summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorOlivier CrĂȘte <olivier.crete@collabora.com>2014-06-26 15:08:46 -0400
committerOlivier CrĂȘte <olivier.crete@collabora.com>2014-06-26 15:08:46 -0400
commitc2583cae90f85c313b0ac645857cc463c504600b (patch)
tree8ac92a61c771fc24c3b440e9b3b57ba6f9f22aec
parent7992174a1a367c2f3cf3bc53fc1bd76fd8a365d0 (diff)
GstDeviceMonitor: Rename from GstGlobalDeviceMonitor
-rw-r--r--docs/gst/gstreamer-docs.sgml2
-rw-r--r--docs/gst/gstreamer-sections.txt44
-rw-r--r--gst/Makefile.am4
-rw-r--r--gst/gst.h2
-rw-r--r--gst/gstdevicemonitor.c (renamed from gst/gstglobaldevicemonitor.c)124
-rw-r--r--gst/gstdevicemonitor.h105
-rw-r--r--gst/gstglobaldevicemonitor.h105
-rw-r--r--win32/common/libgstreamer.def20
8 files changed, 202 insertions, 204 deletions
diff --git a/docs/gst/gstreamer-docs.sgml b/docs/gst/gstreamer-docs.sgml
index e73ac6ed8..3a2c7af5c 100644
--- a/docs/gst/gstreamer-docs.sgml
+++ b/docs/gst/gstreamer-docs.sgml
@@ -117,7 +117,7 @@ Windows. It is released under the GNU Library General Public License
<chapter id="gstreamer-device-probing">
<title>GStreamer Device Discovery and Device Probing</title>
- <xi:include href="xml/gstglobaldevicemonitor.xml" />
+ <xi:include href="xml/gstdevicemonitor.xml" />
<xi:include href="xml/gstdevice.xml" />
<xi:include href="xml/gstdeviceprovider.xml" />
<xi:include href="xml/gstdeviceproviderfactory.xml" />
diff --git a/docs/gst/gstreamer-sections.txt b/docs/gst/gstreamer-sections.txt
index f471c3f99..874a431bf 100644
--- a/docs/gst/gstreamer-sections.txt
+++ b/docs/gst/gstreamer-sections.txt
@@ -3411,29 +3411,29 @@ gst_device_provider_factory_get_type
</SECTION>
<SECTION>
-<FILE>gstglobaldevicemonitor</FILE>
-<TITLE>GstGlobalDeviceMonitor</TITLE>
-GstGlobalDeviceMonitor
-GstGlobalDeviceMonitorClass
-gst_global_device_monitor_get_bus
-gst_global_device_monitor_get_caps_filter
-gst_global_device_monitor_get_classes_filter
-gst_global_device_monitor_get_devices
-gst_global_device_monitor_new
-gst_global_device_monitor_set_caps_filter
-gst_global_device_monitor_set_classes_filter
-gst_global_device_monitor_start
-gst_global_device_monitor_stop
+<FILE>gstdevicemonitor</FILE>
+<TITLE>GstDeviceMonitor</TITLE>
+GstDeviceMonitor
+GstDeviceMonitorClass
+gst_device_monitor_get_bus
+gst_device_monitor_get_caps_filter
+gst_device_monitor_get_classes_filter
+gst_device_monitor_get_devices
+gst_device_monitor_new
+gst_device_monitor_set_caps_filter
+gst_device_monitor_set_classes_filter
+gst_device_monitor_start
+gst_device_monitor_stop
<SUBSECTION Standard>
-GstGlobalDeviceMonitorPrivate
-GST_GLOBAL_DEVICE_MONITOR
-GST_GLOBAL_DEVICE_MONITOR_CAST
-GST_GLOBAL_DEVICE_MONITOR_CLASS
-GST_GLOBAL_DEVICE_MONITOR_GET_CLASS
-GST_IS_GLOBAL_DEVICE_MONITOR
-GST_IS_GLOBAL_DEVICE_MONITOR_CLASS
-GST_TYPE_GLOBAL_DEVICE_MONITOR
-gst_global_device_monitor_get_type
+GstDeviceMonitorPrivate
+GST_DEVICE_MONITOR
+GST_DEVICE_MONITOR_CAST
+GST_DEVICE_MONITOR_CLASS
+GST_DEVICE_MONITOR_GET_CLASS
+GST_IS_DEVICE_MONITOR
+GST_IS_DEVICE_MONITOR_CLASS
+GST_TYPE_DEVICE_MONITOR
+gst_device_monitor_get_type
</SECTION>
diff --git a/gst/Makefile.am b/gst/Makefile.am
index ffab2339f..2e2a79cc5 100644
--- a/gst/Makefile.am
+++ b/gst/Makefile.am
@@ -80,7 +80,7 @@ libgstreamer_@GST_API_VERSION@_la_SOURCES = \
gstevent.c \
gstformat.c \
gstghostpad.c \
- gstglobaldevicemonitor.c \
+ gstdevicemonitor.c \
gstinfo.c \
gstiterator.c \
gstatomicqueue.c \
@@ -184,7 +184,7 @@ gst_headers = \
gstevent.h \
gstformat.h \
gstghostpad.h \
- gstglobaldevicemonitor.h \
+ gstdevicemonitor.h \
gstinfo.h \
gstiterator.h \
gstatomicqueue.h \
diff --git a/gst/gst.h b/gst/gst.h
index 07c629117..65328091b 100644
--- a/gst/gst.h
+++ b/gst/gst.h
@@ -49,7 +49,7 @@
#include <gst/gsterror.h>
#include <gst/gstevent.h>
#include <gst/gstghostpad.h>
-#include <gst/gstglobaldevicemonitor.h>
+#include <gst/gstdevicemonitor.h>
#include <gst/gstinfo.h>
#include <gst/gstiterator.h>
#include <gst/gstmessage.h>
diff --git a/gst/gstdevicemonitor.h b/gst/gstdevicemonitor.h
new file mode 100644
index 000000000..9bce5d743
--- /dev/null
+++ b/gst/gstdevicemonitor.h
@@ -0,0 +1,105 @@
+/* GStreamer
+ * Copyright (C) 2013 Olivier Crete <olivier.crete@collabora.com>
+ *
+ * gstdevicemonitor.c: Device monitor
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
+ */
+
+
+#ifndef __GST_DEVICE_MONITOR_H__
+#define __GST_DEVICE_MONITOR_H__
+
+#include <gst/gstobject.h>
+#include <gst/gstdevice.h>
+#include <gst/gstdeviceprovider.h>
+#include <gst/gstdeviceproviderfactory.h>
+
+G_BEGIN_DECLS
+
+typedef struct _GstDeviceMonitor GstDeviceMonitor;
+typedef struct _GstDeviceMonitorPrivate GstDeviceMonitorPrivate;
+typedef struct _GstDeviceMonitorClass GstDeviceMonitorClass;
+
+#define GST_TYPE_DEVICE_MONITOR (gst_device_monitor_get_type())
+#define GST_IS_DEVICE_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GST_TYPE_DEVICE_MONITOR))
+#define GST_IS_DEVICE_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GST_TYPE_DEVICE_MONITOR))
+#define GST_DEVICE_MONITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GST_TYPE_DEVICE_MONITOR, GstDeviceMonitorClass))
+#define GST_DEVICE_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GST_TYPE_DEVICE_MONITOR, GstDeviceMonitor))
+#define GST_DEVICE_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GST_TYPE_DEVICE_MONITOR, GstDeviceMonitorClass))
+#define GST_DEVICE_MONITOR_CAST(obj) ((GstDeviceMonitor *)(obj))
+
+/**
+ * GstDeviceMonitor:
+ * @parent: the parent #GstObject structure
+ *
+ * Opaque device monitor object structure.
+ *
+ * Since: 1.4
+ */
+struct _GstDeviceMonitor {
+ GstObject parent;
+
+ /*< private >*/
+
+ GstDeviceMonitorPrivate *priv;
+
+ gpointer _gst_reserved[GST_PADDING];
+};
+
+/**
+ * GstDeviceMonitorClass:
+ * @parent_class: the parent #GstObjectClass structure
+ *
+ * Opaque device monitor class structure.
+ *
+ * Since: 1.4
+ */
+struct _GstDeviceMonitorClass {
+ GstObjectClass parent_class;
+
+ /*< private >*/
+ gpointer _gst_reserved[GST_PADDING];
+};
+
+GType gst_device_monitor_get_type (void);
+
+GstDeviceMonitor * gst_device_monitor_new (void);
+
+GstBus * gst_device_monitor_get_bus (GstDeviceMonitor * monitor);
+
+GList * gst_device_monitor_get_devices (GstDeviceMonitor * monitor);
+
+
+gboolean gst_device_monitor_start (GstDeviceMonitor * monitor);
+
+void gst_device_monitor_stop (GstDeviceMonitor * monitor);
+
+
+void gst_device_monitor_set_classes_filter (GstDeviceMonitor * monitor,
+ const gchar * classes);
+
+gchar * gst_device_monitor_get_classes_filter (GstDeviceMonitor * monitor);
+
+
+void gst_device_monitor_set_caps_filter (GstDeviceMonitor * monitor,
+ GstCaps * caps);
+
+GstCaps * gst_device_monitor_get_caps_filter (GstDeviceMonitor * monitor);
+
+G_END_DECLS
+
+#endif /* __GST_DEVICE_MONITOR_H__ */
diff --git a/gst/gstglobaldevicemonitor.h b/gst/gstglobaldevicemonitor.h
deleted file mode 100644
index c0b623a55..000000000
--- a/gst/gstglobaldevicemonitor.h
+++ /dev/null
@@ -1,105 +0,0 @@
-/* GStreamer
- * Copyright (C) 2013 Olivier Crete <olivier.crete@collabora.com>
- *
- * gstglobaldevicemonitor.c: Global device monitor
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
- */
-
-
-#ifndef __GST_GLOBAL_DEVICE_MONITOR_H__
-#define __GST_GLOBAL_DEVICE_MONITOR_H__
-
-#include <gst/gstobject.h>
-#include <gst/gstdevice.h>
-#include <gst/gstdeviceprovider.h>
-#include <gst/gstdeviceproviderfactory.h>
-
-G_BEGIN_DECLS
-
-typedef struct _GstGlobalDeviceMonitor GstGlobalDeviceMonitor;
-typedef struct _GstGlobalDeviceMonitorPrivate GstGlobalDeviceMonitorPrivate;
-typedef struct _GstGlobalDeviceMonitorClass GstGlobalDeviceMonitorClass;
-
-#define GST_TYPE_GLOBAL_DEVICE_MONITOR (gst_global_device_monitor_get_type())
-#define GST_IS_GLOBAL_DEVICE_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GST_TYPE_GLOBAL_DEVICE_MONITOR))
-#define GST_IS_GLOBAL_DEVICE_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GST_TYPE_GLOBAL_DEVICE_MONITOR))
-#define GST_GLOBAL_DEVICE_MONITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GST_TYPE_GLOBAL_DEVICE_MONITOR, GstGlobalDeviceMonitorClass))
-#define GST_GLOBAL_DEVICE_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GST_TYPE_GLOBAL_DEVICE_MONITOR, GstGlobalDeviceMonitor))
-#define GST_GLOBAL_DEVICE_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GST_TYPE_GLOBAL_DEVICE_MONITOR, GstGlobalDeviceMonitorClass))
-#define GST_GLOBAL_DEVICE_MONITOR_CAST(obj) ((GstGlobalDeviceMonitor *)(obj))
-
-/**
- * GstGlobalDeviceMonitor:
- * @parent: the parent #GstObject structure
- *
- * Opaque global device monitor object structure.
- *
- * Since: 1.4
- */
-struct _GstGlobalDeviceMonitor {
- GstObject parent;
-
- /*< private >*/
-
- GstGlobalDeviceMonitorPrivate *priv;
-
- gpointer _gst_reserved[GST_PADDING];
-};
-
-/**
- * GstGlobalDeviceMonitorClass:
- * @parent_class: the parent #GstObjectClass structure
- *
- * Opaque global device monitor class structure.
- *
- * Since: 1.4
- */
-struct _GstGlobalDeviceMonitorClass {
- GstObjectClass parent_class;
-
- /*< private >*/
- gpointer _gst_reserved[GST_PADDING];
-};
-
-GType gst_global_device_monitor_get_type (void);
-
-GstGlobalDeviceMonitor * gst_global_device_monitor_new (void);
-
-GstBus * gst_global_device_monitor_get_bus (GstGlobalDeviceMonitor * monitor);
-
-GList * gst_global_device_monitor_get_devices (GstGlobalDeviceMonitor * monitor);
-
-
-gboolean gst_global_device_monitor_start (GstGlobalDeviceMonitor * monitor);
-
-void gst_global_device_monitor_stop (GstGlobalDeviceMonitor * monitor);
-
-
-void gst_global_device_monitor_set_classes_filter (GstGlobalDeviceMonitor * monitor,
- const gchar * classes);
-
-gchar * gst_global_device_monitor_get_classes_filter (GstGlobalDeviceMonitor * monitor);
-
-
-void gst_global_device_monitor_set_caps_filter (GstGlobalDeviceMonitor * monitor,
- GstCaps * caps);
-
-GstCaps * gst_global_device_monitor_get_caps_filter (GstGlobalDeviceMonitor * monitor);
-
-G_END_DECLS
-
-#endif /* __GST_GLOBAL_DEVICE_MONITOR_H__ */
diff --git a/win32/common/libgstreamer.def b/win32/common/libgstreamer.def
index 8579962af..b0c105c73 100644
--- a/win32/common/libgstreamer.def
+++ b/win32/common/libgstreamer.def
@@ -415,6 +415,16 @@ EXPORTS
gst_device_get_type
gst_device_has_classes
gst_device_has_classesv
+ gst_device_monitor_get_bus
+ gst_device_monitor_get_caps_filter
+ gst_device_monitor_get_classes_filter
+ gst_device_monitor_get_devices
+ gst_device_monitor_get_type
+ gst_device_monitor_new
+ gst_device_monitor_set_caps_filter
+ gst_device_monitor_set_classes_filter
+ gst_device_monitor_start
+ gst_device_monitor_stop
gst_device_provider_can_monitor
gst_device_provider_class_add_metadata
gst_device_provider_class_add_static_metadata
@@ -605,16 +615,6 @@ EXPORTS
gst_ghost_pad_new_no_target
gst_ghost_pad_new_no_target_from_template
gst_ghost_pad_set_target
- gst_global_device_monitor_get_bus
- gst_global_device_monitor_get_caps_filter
- gst_global_device_monitor_get_classes_filter
- gst_global_device_monitor_get_devices
- gst_global_device_monitor_get_type
- gst_global_device_monitor_new
- gst_global_device_monitor_set_caps_filter
- gst_global_device_monitor_set_classes_filter
- gst_global_device_monitor_start
- gst_global_device_monitor_stop
gst_init
gst_init_check
gst_init_get_option_group
diff --git a/gst/gstglobaldevicemonitor.c b/gst/gstdevicemonitor.c
index 0c9dda961..9d59211e6 100644
--- a/gst/gstglobaldevicemonitor.c
+++ b/gst/gstdevicemonitor.c
@@ -1,7 +1,7 @@
/* GStreamer
* Copyright (C) 2013 Olivier Crete <olivier.crete@collabora.com>
*
* gstglobaldevicemonitor.c: Global device monitor
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Library General Public
@@ -20,13 +20,13 @@
*/
/**
* SECTION:gstglobaldevicemonitor
* @short_description: A global device monitor and prober
* @see_also: #GstDevice, #GstDeviceProvider
*
* Applications should create a #GstGlobalDeviceMonitor when they want
* to probe, list and monitor devices of a specific type. The
* #GstGlobalDeviceMonitor will create the appropriate
* #GstDeviceProvider objects and manage them. It will then post
* messages on its #GstBus for devices that have been added and
* removed.
@@ -40,9 +40,9 @@
#endif
#include "gst_private.h"
-#include "gstglobaldevicemonitor.h"
+#include "gstdevicemonitor.h"
-struct _GstGlobalDeviceMonitorPrivate
+struct _GstDeviceMonitorPrivate
{
gboolean started;
@@ -56,24 +56,23 @@ struct _GstGlobalDeviceMonitorPrivate
};
-G_DEFINE_TYPE (GstGlobalDeviceMonitor, gst_global_device_monitor,
- GST_TYPE_OBJECT);
+G_DEFINE_TYPE (GstDeviceMonitor, gst_device_monitor, GST_TYPE_OBJECT);
-static void gst_global_device_monitor_dispose (GObject * object);
+static void gst_device_monitor_dispose (GObject * object);
static void
-gst_global_device_monitor_class_init (GstGlobalDeviceMonitorClass * klass)
+gst_device_monitor_class_init (GstDeviceMonitorClass * klass)
{
GObjectClass *object_class = G_OBJECT_CLASS (klass);
- g_type_class_add_private (klass, sizeof (GstGlobalDeviceMonitorPrivate));
+ g_type_class_add_private (klass, sizeof (GstDeviceMonitorPrivate));
- object_class->dispose = gst_global_device_monitor_dispose;
+ object_class->dispose = gst_device_monitor_dispose;
}
static void
bus_sync_message (GstBus * bus, GstMessage * message,
- GstGlobalDeviceMonitor * monitor)
+ GstDeviceMonitor * monitor)
{
GstMessageType type = GST_MESSAGE_TYPE (message);
@@ -101,12 +100,12 @@ bus_sync_message (GstBus * bus, GstMessage * message,
static void
-gst_global_device_monitor_init (GstGlobalDeviceMonitor * self)
+gst_device_monitor_init (GstDeviceMonitor * self)
{
GList *factories;
self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
- GST_TYPE_GLOBAL_DEVICE_MONITOR, GstGlobalDeviceMonitorPrivate);
+ GST_TYPE_DEVICE_MONITOR, GstDeviceMonitorPrivate);
self->priv->bus = gst_bus_new ();
gst_bus_set_flushing (self->priv->bus, TRUE);
@@ -116,8 +115,8 @@ gst_global_device_monitor_init (GstGlobalDeviceMonitor * self)
self->priv->classes = g_strdup ("");
factories =
- gst_device_provider_factory_list_get_device_providers (self->priv->
- classes, 1);
+ gst_device_provider_factory_list_get_device_providers (self->
+ priv->classes, 1);
while (factories) {
GstDeviceProviderFactory *factory = factories->data;
@@ -141,7 +140,7 @@ gst_global_device_monitor_init (GstGlobalDeviceMonitor * self)
static void
-gst_global_device_monitor_remove (GstGlobalDeviceMonitor * self, guint i)
+gst_device_monitor_remove (GstDeviceMonitor * self, guint i)
{
GstDeviceProvider *provider = g_ptr_array_index (self->priv->providers, i);
GstBus *bus;
@@ -156,15 +155,15 @@ gst_global_device_monitor_remove (GstGlobalDeviceMonitor * self, guint i)
}
static void
-gst_global_device_monitor_dispose (GObject * object)
+gst_device_monitor_dispose (GObject * object)
{
- GstGlobalDeviceMonitor *self = GST_GLOBAL_DEVICE_MONITOR (object);
+ GstDeviceMonitor *self = GST_DEVICE_MONITOR (object);
g_return_if_fail (self->priv->started == FALSE);
if (self->priv->providers) {
while (self->priv->providers->len)
- gst_global_device_monitor_remove (self, self->priv->providers->len - 1);
+ gst_device_monitor_remove (self, self->priv->providers->len - 1);
g_ptr_array_unref (self->priv->providers);
self->priv->providers = NULL;
}
@@ -173,15 +172,15 @@ gst_global_device_monitor_dispose (GObject * object)
g_free (self->priv->classes);
gst_object_replace ((GstObject **) & self->priv->bus, NULL);
- G_OBJECT_CLASS (gst_global_device_monitor_parent_class)->dispose (object);
+ G_OBJECT_CLASS (gst_device_monitor_parent_class)->dispose (object);
}
/**
- * gst_global_device_monitor_get_devices:
+ * gst_device_monitor_get_devices:
* @monitor: A #GstDeviceProvider
*
* Gets a list of devices from all of the relevant monitors. This may actually
- * probe the hardware if the global monitor is not currently started.
+ * probe the hardware if the monitor is not currently started.
*
* Returns: (transfer full) (element-type GstDevice): a #GList of
* #GstDevice
@@ -190,13 +189,13 @@ gst_global_device_monitor_dispose (GObject * object)
*/
GList *
-gst_global_device_monitor_get_devices (GstGlobalDeviceMonitor * monitor)
+gst_device_monitor_get_devices (GstDeviceMonitor * monitor)
{
GList *devices = NULL;
guint i;
guint cookie;
- g_return_val_if_fail (GST_IS_GLOBAL_DEVICE_MONITOR (monitor), NULL);
+ g_return_val_if_fail (GST_IS_DEVICE_MONITOR (monitor), NULL);
GST_OBJECT_LOCK (monitor);
@@ -242,8 +241,8 @@ again:
}
/**
- * gst_global_device_monitor_start:
- * @monitor: A #GstGlobalDeviceMonitor
+ * gst_device_monitor_start:
+ * @monitor: A #GstDeviceMonitor
*
* Starts monitoring the devices, one this has succeeded, the
* %GST_MESSAGE_DEVICE_ADDED and %GST_MESSAGE_DEVICE_REMOVED messages
@@ -255,11 +254,11 @@ again:
*/
gboolean
-gst_global_device_monitor_start (GstGlobalDeviceMonitor * monitor)
+gst_device_monitor_start (GstDeviceMonitor * monitor)
{
guint i;
- g_return_val_if_fail (GST_IS_GLOBAL_DEVICE_MONITOR (monitor), FALSE);
+ g_return_val_if_fail (GST_IS_DEVICE_MONITOR (monitor), FALSE);
GST_OBJECT_LOCK (monitor);
@@ -291,7 +290,7 @@ gst_global_device_monitor_start (GstGlobalDeviceMonitor * monitor)
}
/**
- * gst_global_device_monitor_stop:
+ * gst_device_monitor_stop:
* @monitor: A #GstDeviceProvider
*
* Stops monitoring the devices.
@@ -299,11 +298,11 @@ gst_global_device_monitor_start (GstGlobalDeviceMonitor * monitor)
* Since: 1.4
*/
void
-gst_global_device_monitor_stop (GstGlobalDeviceMonitor * monitor)
+gst_device_monitor_stop (GstDeviceMonitor * monitor)
{
guint i;
- g_return_if_fail (GST_IS_GLOBAL_DEVICE_MONITOR (monitor));
+ g_return_if_fail (GST_IS_DEVICE_MONITOR (monitor));
gst_bus_set_flushing (monitor->priv->bus, TRUE);
@@ -316,8 +315,8 @@ gst_global_device_monitor_stop (GstGlobalDeviceMonitor * monitor)
}
/**
* gst_global_device_monitor_set_classes_filter:
* @monitor: the global device monitor
* @classes: device classes to use as filter
*
* Filter devices monitored by device class, e.g. in case you are only
@@ -327,13 +326,13 @@ gst_global_device_monitor_stop (GstGlobalDeviceMonitor * monitor)
* Since: 1.4
*/
void
-gst_global_device_monitor_set_classes_filter (GstGlobalDeviceMonitor * monitor,
+gst_device_monitor_set_classes_filter (GstDeviceMonitor * monitor,
const gchar * classes)
{
GList *factories = NULL;
guint i;
- g_return_if_fail (GST_IS_GLOBAL_DEVICE_MONITOR (monitor));
+ g_return_if_fail (GST_IS_DEVICE_MONITOR (monitor));
g_return_if_fail (!monitor->priv->started);
GST_OBJECT_LOCK (monitor);
@@ -369,7 +368,7 @@ gst_global_device_monitor_set_classes_filter (GstGlobalDeviceMonitor * monitor,
*/
monitor->priv->cookie++;
- gst_global_device_monitor_remove (monitor, i);
+ gst_device_monitor_remove (monitor, i);
i--;
}
}
@@ -399,8 +398,8 @@ gst_global_device_monitor_set_classes_filter (GstGlobalDeviceMonitor * monitor,
}
/**
* gst_global_device_monitor_get_classes_filter:
* @monitor: the global device monitor
*
* Return the type (device classes) filter active for device filtering.
*
@@ -409,11 +408,11 @@ gst_global_device_monitor_set_classes_filter (GstGlobalDeviceMonitor * monitor,
* Since: 1.4
*/
gchar *
-gst_global_device_monitor_get_classes_filter (GstGlobalDeviceMonitor * monitor)
+gst_device_monitor_get_classes_filter (GstDeviceMonitor * monitor)
{
gchar *res;
- g_return_val_if_fail (GST_IS_GLOBAL_DEVICE_MONITOR (monitor), 0);
+ g_return_val_if_fail (GST_IS_DEVICE_MONITOR (monitor), 0);
GST_OBJECT_LOCK (monitor);
res = g_strdup (monitor->priv->classes);
@@ -423,8 +422,8 @@ gst_global_device_monitor_get_classes_filter (GstGlobalDeviceMonitor * monitor)
}
/**
* gst_global_device_monitor_set_caps_filter:
* @monitor: the global device monitor
* @caps: caps to filter
*
* Set caps to use as filter for devices. By default ANY caps are used,
@@ -433,10 +432,9 @@ gst_global_device_monitor_get_classes_filter (GstGlobalDeviceMonitor * monitor)
* Since: 1.4
*/
void
-gst_global_device_monitor_set_caps_filter (GstGlobalDeviceMonitor * monitor,
- GstCaps * caps)
+gst_device_monitor_set_caps_filter (GstDeviceMonitor * monitor, GstCaps * caps)
{
- g_return_if_fail (GST_IS_GLOBAL_DEVICE_MONITOR (monitor));
+ g_return_if_fail (GST_IS_DEVICE_MONITOR (monitor));
g_return_if_fail (GST_IS_CAPS (caps));
GST_OBJECT_LOCK (monitor);
@@ -445,21 +443,21 @@ gst_global_device_monitor_set_caps_filter (GstGlobalDeviceMonitor * monitor,
}
/**
- * gst_global_device_monitor_get_caps_filter:
- * @monitor: a global device monitor
+ * gst_device_monitor_get_caps_filter:
+ * @monitor: a device monitor
*
* Get the #GstCaps filter set by gst_global_device_monitor_set_caps_filter().
*
* Returns: (transfer full): the filter caps that are active (or ANY caps)
*
* Since: 1.4
*/
GstCaps *
-gst_global_device_monitor_get_caps_filter (GstGlobalDeviceMonitor * monitor)
+gst_device_monitor_get_caps_filter (GstDeviceMonitor * monitor)
{
GstCaps *res;
- g_return_val_if_fail (GST_IS_GLOBAL_DEVICE_MONITOR (monitor), NULL);
+ g_return_val_if_fail (GST_IS_DEVICE_MONITOR (monitor), NULL);
GST_OBJECT_LOCK (monitor);
res = gst_caps_ref (monitor->priv->caps);
@@ -469,34 +467,34 @@ gst_global_device_monitor_get_caps_filter (GstGlobalDeviceMonitor * monitor)
}
/**
- * gst_global_device_monitor_new:
+ * gst_device_monitor_new:
*
- * Create a new #GstGlobalDeviceMonitor
+ * Create a new #GstDeviceMonitor
*
- * Returns: (transfer full): a new global device monitor.
+ * Returns: (transfer full): a new device monitor.
*
* Since: 1.4
*/
-GstGlobalDeviceMonitor *
-gst_global_device_monitor_new (void)
+GstDeviceMonitor *
+gst_device_monitor_new (void)
{
- return g_object_new (GST_TYPE_GLOBAL_DEVICE_MONITOR, NULL);
+ return g_object_new (GST_TYPE_DEVICE_MONITOR, NULL);
}
/**
- * gst_global_device_monitor_get_bus:
+ * gst_device_monitor_get_bus:
* @monitor: a #GstDeviceProvider
*
* Gets the #GstBus of this #GstGlobalDeviceMonitor
*
* Returns: (transfer full): a #GstBus
*
* Since: 1.4
*/
GstBus *
-gst_global_device_monitor_get_bus (GstGlobalDeviceMonitor * monitor)
+gst_device_monitor_get_bus (GstDeviceMonitor * monitor)
{
- g_return_val_if_fail (GST_IS_GLOBAL_DEVICE_MONITOR (monitor), NULL);
+ g_return_val_if_fail (GST_IS_DEVICE_MONITOR (monitor), NULL);
return gst_object_ref (monitor->priv->bus);
}
@@ -1,7 +1,7 @@
* Copyright (C) 2013 Olivier Crete <olivier.crete@collabora.com>
*
- * gstglobaldevicemonitor.c: Global device monitor
+ * gstdevicemonitor.c: device monitor
*
* This library is free software; you can redistribute it and/or
@@ -20,13 +20,13 @@
*/
/**
- * SECTION:gstglobaldevicemonitor
- * @short_description: A global device monitor and prober
+ * SECTION:gstdevicemonitor
+ * @short_description: A device monitor and prober
* @see_also: #GstDevice, #GstDeviceProvider
*
@@ -20,13 +20,13 @@
* @see_also: #GstDevice, #GstDeviceProvider
*
- * Applications should create a #GstGlobalDeviceMonitor when they want
+ * Applications should create a #GstDeviceMonitor when they want
* to probe, list and monitor devices of a specific type. The
@@ -20,13 +20,13 @@
* to probe, list and monitor devices of a specific type. The
- * #GstGlobalDeviceMonitor will create the appropriate
+ * #GstDeviceMonitor will create the appropriate
* #GstDeviceProvider objects and manage them. It will then post
* messages on its #GstBus for devices that have been added and
@@ -316,8 +315,8 @@ gst_global_device_monitor_stop (GstGlobalDeviceMonitor * monitor)
}
/**
- * gst_global_device_monitor_set_classes_filter:
- * @monitor: the global device monitor
+ * gst_device_monitor_set_classes_filter:
+ * @monitor: the device monitor
* @classes: device classes to use as filter
*
@@ -399,8 +398,8 @@ gst_global_device_monitor_set_classes_filter (GstGlobalDeviceMonitor * monitor,
}
/**
- * gst_global_device_monitor_get_classes_filter:
- * @monitor: the global device monitor
+ * gst_device_monitor_get_classes_filter:
+ * @monitor: the device monitor
*
* Return the type (device classes) filter active for device filtering.
@@ -423,8 +422,8 @@ gst_global_device_monitor_get_classes_filter (GstGlobalDeviceMonitor * monitor)
}
/**
- * gst_global_device_monitor_set_caps_filter:
- * @monitor: the global device monitor
+ * gst_device_monitor_set_caps_filter:
+ * @monitor: the device monitor
* @caps: caps to filter
*
@@ -445,21 +443,21 @@ gst_global_device_monitor_set_caps_filter (GstGlobalDeviceMonitor * monitor,
*
- * Get the #GstCaps filter set by gst_global_device_monitor_set_caps_filter().
+ * Get the #GstCaps filter set by gst_device_monitor_set_caps_filter().
*
* Returns: (transfer full): the filter caps that are active (or ANY caps)
@@ -469,34 +467,34 @@ gst_global_device_monitor_get_caps_filter (GstGlobalDeviceMonitor * monitor)
* @monitor: a #GstDeviceProvider
*
- * Gets the #GstBus of this #GstGlobalDeviceMonitor
+ * Gets the #GstBus of this #GstDeviceMonitor
*
* Returns: (transfer full): a #GstBus